==> cxf-bundle-2.1.1-sources.jar: org/apache/cxf/binding/corba/types/HandlerIterator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.binding.corba.types;

import java.util.Iterator;

import org.apache.cxf.binding.corba.CorbaMessage;
import org.apache.cxf.binding.corba.CorbaStreamable;

public class HandlerIterator implements Iterator<CorbaObjectHandler> {
    final CorbaStreamable[] params;
    int count;
    CorbaObjectHandler next;
    boolean isServer;
    
    public HandlerIterator(CorbaMessage msg, boolean server) {
        params = msg.getStreamableArguments();
        isServer = server;
        if (!isServer && msg.getStreamableReturn() != null) {
            next = msg.getStreamableReturn().getObject();
        }
    }
    
    public boolean hasNext() {
        if (next == null) {
            while (next == null && count < params.length) {
                int mode = params[count].getMode();
                int value = org.omg.CORBA.ARG_OUT.value;
                if (isServer) {
                    value = org.omg.CORBA.ARG_IN.value;
                }
                if (mode == value
                    || mode == org.omg.CORBA.ARG_INOUT.value) {
                    next = params[count].getObject();
                }
                count++;
            }
        }
        return next != null;
    }
    
    public CorbaObjectHandler next() {
        CorbaObjectHandler current = next;
        next = null;
        return current;
    }
    
    public void remove() {
    }
}

==> cxf-bundle-2.5.1-sources.jar: org/apache/cxf/binding/corba/types/HandlerIterator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.binding.corba.types;

import java.util.Iterator;

import org.apache.cxf.binding.corba.CorbaMessage;
import org.apache.cxf.binding.corba.CorbaStreamable;

public class HandlerIterator implements Iterator<CorbaObjectHandler> {
    final CorbaStreamable[] params;
    int count;
    CorbaObjectHandler next;
    boolean isServer;
    
    public HandlerIterator(CorbaMessage msg, boolean server) {
        params = msg.getStreamableArguments();
        isServer = server;
        if (!isServer && msg.getStreamableReturn() != null) {
            next = msg.getStreamableReturn().getObject();
        }
    }
    
    public boolean hasNext() {
        if (next == null) {
            while (next == null && count < params.length) {
                int mode = params[count].getMode();
                int value = org.omg.CORBA.ARG_OUT.value;
                if (isServer) {
                    value = org.omg.CORBA.ARG_IN.value;
                }
                if (mode == value
                    || mode == org.omg.CORBA.ARG_INOUT.value) {
                    next = params[count].getObject();
                }
                if (!isServer 
                    && mode == org.omg.CORBA.ARG_INOUT.value
                    && next instanceof CorbaPrimitiveHandler) {
                    CorbaPrimitiveHandler prim = (CorbaPrimitiveHandler)next;
                    prim.clear();
                }
                count++;
            }
        }
        return next != null;
    }
    
    public CorbaObjectHandler next() {
        CorbaObjectHandler current = next;
        next = null;
        return current;
    }
    
    public void remove() {
    }
}
